.. _`Installation`:

Installation
============

kiste works with python >= version 3.3.

.. note::
  
  - above versions only tested other may work also


1. `clone repository`_
2. `download archive`_
3. `pip`_

.. _`clone repository`: 

1. clone repository
------------------- 

Install::

  hg clone https://igraltist@bitbucket.org/igraltist/laptop-pm
  cd laptop-pm
  python setup.py install or pip install .

Upgrade::

  pip install --upgrade .

.. _`download archive`:

2. download archive
-------------------

Install::

  wget https://bitbucket.org/igraltist/laptop-pm/get/tip.tar.bz2 
  # for alternative archive use zip or gz as suffix
  tar xvjf tip.tar.bz2
  cd laptop-pm
  pip install .

.. _`pip`:

3. pip
------

Install::

  pip install laptop-pm

